cargo-coverage 0.1.1

A Cargo plugin for generating code coverage data.
cargo-coverage-0.1.1 is not a library.

Cargo Coverage

Generate coverage information for your Rust project. The generated .lcov file can be used by various tools to generate coverage reports.

License

cargo-coverage is distributed under the terms of both the MIT license and the Apache License (Version 2.0).

See LICENSE-APACHE, LICENSE-MIT for details.